@@ -4,9 +4,8 @@ OC.L10N.register(
     "Notes" : "Nodiadau",
     "Error" : "Gwall",
     "New note" : "Nodyn newydd",
-    "Open in edit mode" : "Agor yn y modd golygu",
-    "Open in preview mode" : "Agor yn y modd rhagolwg",
-    "Display mode for notes" : "Modd arddangos nodiadau",
+    "Preview" : "Rhagolwg",
+    "Files" : "Ffeiliau",
     "All notes" : "Pob nodyn",
     "No notes yet" : "Dim nodiadau eto",
     "Remove from favorites" : "Remove from favorites",
@@ -14,7 +13,6 @@ OC.L10N.register(
     "Share" : "Rhannu",
     "Rename" : "Rename",
     "Edit" : "Golygu",
-    "Preview" : "Rhagolwg",
     "Today" : "Heddiw",
     "Yesterday" : "Ddoe",
     "This week" : "Wythnos yma",
