@@ -8,12 +8,14 @@ OC.L10N.register(
     "Undo Delete" : "Annuller Slet",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
     "Notes settings" : "Noter indstillinger",
-    "Open in edit mode" : "Åbn i redigeringstilstand",
-    "Open in preview mode" : "Åbn forhåndsvisning",
+    "Rich text" : "Formateret tekst",
+    "Plain text" : "Rå tekst",
+    "Preview" : "Forhåndsvis",
     "Insert image" : "Indsæt billede",
+    "Display" : "Vis",
     "File extension" : "Filendelse",
-    "Display mode for notes" : "Visningstilstand for noter",
-    "Action" : "Handling",
+    "Files" : "Filer",
+    "Notes folder" : "Noter mappe",
     "All notes" : "Alle noter",
     "Categories" : "Kategorier",
     "No notes yet" : "Ingen noter endnu",
@@ -23,8 +25,7 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Delete note" : "Slet note",
     "Use current version" : "Brug aktuelle version",
-    "Edit" : "Rediger",
-    "Preview" : "Forhåndsvis",
+    "Edit" : "Redigér",
     "Today" : "I dag",
     "Yesterday" : "I går",
     "This week" : "Denne uge",
