@@ -5,24 +5,22 @@ OC.L10N.register(
     "Error" : "Error",
     "New note" : "Nota nueva",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Action" : "Acción",
-    "Open in edit mode" : "Abrir en modo edición",
-    "Open in preview mode" : "Abrir en modo previsualización",
+    "Preview" : "Previsualizar",
+    "Files" : "Archivos",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "No notes yet" : "Aún no hay notas",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
     "Share" : "Compartir",
     "Rename" : "Rename",
     "Delete note" : "Borrar nota",
-    "Remove from favorites" : "Eliminar de favoritos",
-    "Add to favorites" : "Agregar a tus favoritos",
     "Edit" : "Editar",
-    "Preview" : "Previsualizar",
-    "Loading …" : "Cargando …",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
+    "Loading …" : "Cargando …",
     "Uncategorized" : "Sin categoría",
     "Tasks" : "Tareas"
 },
