@@ -16,40 +16,24 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
     "Notes settings" : "Notes settings",
     "Please see Nextcloud server log for details." : "Please see Nextcloud server log for details.",
-    "User defined" : "User defined",
-    "Open in rich text mode" : "Open in rich text mode",
-    "Open in edit mode" : "Open in edit mode",
-    "Open in preview mode" : "Open in preview mode",
-    "CTRL" : "CTRL",
+    "Preview" : "Preview",
     "Make the selection bold" : "Make the selection bold",
     "Make the selection italic" : "Make the selection italic",
     "Wrap the selection in quotes" : "Wrap the selection in quotes",
-    "ALT" : "ALT",
     "The selection will be turned into monospace" : "The selection will be turned into monospace",
     "Remove any styles from the selected text" : "Remove any styles from the selected text",
     "Makes the current line a list element" : "Makes the current line a list element",
     "Makes the current line a list element with a number" : "Makes the current line a list element with a number",
     "Toggle heading for current line" : "Toggle heading for current line",
-    "SHIFT" : "SHIFT",
     "Set the current line as a big heading" : "Set the current line as a big heading",
     "Insert link" : "Insert link",
     "Insert image" : "Insert image",
     "Switch between editor and viewer" : "Switch between editor and viewer",
-    "Basics" : "Basics",
-    "Write down your thoughts without any distractions." : "Write down your thoughts without any distractions.",
-    "Organize your notes in categories." : "Organize your notes in categories.",
-    "Notes path" : "Notes path",
-    "Folder to store your notes" : "Folder to store your notes",
-    "Root directory" : "Root directory",
+    "General" : "General",
     "File extension" : "File extension",
-    "File extension for new notes" : "File extension for new notes",
-    "Display mode" : "Display mode",
-    "Display mode for notes" : "Display mode for notes",
-    "Shortcuts" : "Shortcuts",
-    "Use shortcuts to quickly navigate this app." : "Use shortcuts to quickly navigate this app.",
-    "Shortcut" : "Shortcut",
-    "Action" : "Action",
+    "Files" : "ფაილები",
     "Mobile apps" : "Mobile apps",
+    "Shortcuts" : "Shortcuts",
     "All notes" : "All notes",
     "Categories" : "Categories",
     "Create a sample note with Markdown" : "Create a sample note with Markdown",
@@ -59,9 +43,6 @@ OC.L10N.register(
     "Wrong image" : "Wrong image",
     "The file was not uploaded. Check your server logs." : "The file was not uploaded. Check your server logs.",
     "Upload image" : "Upload image",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Install the app for your mobile phone in order to access your notes from everywhere.",
-    "Android app: {notes}" : "Android app: {notes}",
-    "iOS app: {notes}" : "iOS app: {notes}",
     "Rich text editor" : "Rich text editor",
     "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks.",
     "This option can also be changed later on in the Notes app settings." : "This option can also be changed later on in the Notes app settings.",
@@ -84,7 +65,6 @@ OC.L10N.register(
     "Write …" : "Write …",
     "CTRL + /" : "CTRL + /",
     "Edit" : "Edit",
-    "Preview" : "Preview",
     "Exit full screen" : "Exit full screen",
     "Full screen" : "Full screen",
     "Note is read-only. You cannot change it." : "Note is read-only. You cannot change it.",
@@ -99,7 +79,9 @@ OC.L10N.register(
     "Search for notes" : "Search for notes",
     "Loading …" : "Loading …",
     "Find in all categories" : "Find in all categories",
+    "Write down your thoughts without any distractions." : "Write down your thoughts without any distractions.",
     "Use Markdown markups to style your text." : "Use Markdown markups to style your text.",
+    "Organize your notes in categories." : "Organize your notes in categories.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Start writing a note by clicking on “{newnote}” in the app navigation.",
     "Note not found." : "Note not found.",
     "Note is locked." : "Note is locked.",
