@@ -5,26 +5,21 @@ OC.L10N.register(
     "Error" : "შეცდომა",
     "New note" : "ახალი ჩანაწერი",
     "There are unsaved notes. Leaving the page will discard all changes!" : "არსებობს შეუნახავი ჩანაწერები. გვერდის დატოვება ყველა ცვლილებას უარყოფს!",
-    "Open in edit mode" : "გახსენით ცვლილების რეჟიმში",
-    "Open in preview mode" : "გახსენით წინასწარი ჩვენების რეჟიმში",
-    "No notes yet" : "ჯერ ჩანაწერები არაა",
+    "Preview" : "წინასწარი ჩვენება",
+    "Files" : "ფაილები",
     "Categories" : "კატეგორიები",
+    "No notes yet" : "ჯერ ჩანაწერები არაა",
+    "Remove from favorites" : "რჩეულებიდან ამოშლა",
+    "Add to favorites" : "რჩეულებში დამატება",
+    "Share" : "გაზიარება",
+    "Rename" : "Rename",
+    "Delete note" : "ჩანაწერის გაუქმება",
+    "Edit" : "ცვლილება",
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "This week" : "ამ კვირაში",
     "This month" : "ამ თვეში",
-    "Rename" : "სახელის შეცვლა",
-    "Delete note" : "ჩანაწერის გაუქმება",
-    "Remove from favorites" : "რჩეულებიდან ამოშლა",
-    "Add to favorites" : "რჩეულებში დამატება",
-    "Details" : "დეტალები",
-    "Edit" : "ცვლილება",
-    "Preview" : "წინასწარი ჩვენება",
-    "Category" : "კატეგორია",
     "Uncategorized" : "არაკატეგორიზირებული",
-    "Saving failed!" : "შენახვა ვერ მოხერხდა!",
-    "_%n word_::_%n words_" : ["%n სიტყვა","%n სიტყვა"],
-    "Android app" : "Android აპლიკაცია",
-    "iOS app" : "iOS აპლიკაცია"
+    "Tasks" : "დავალებები"
 },
 "nplurals=2; plural=(n!=1);");
