@@ -13,24 +13,16 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
     "Notes settings" : "Užrašų nustatymai",
     "Please see Nextcloud server log for details." : "Išsamesnei informacijai žiūrėkite Nextcloud serverio žurnalą.",
-    "User defined" : "Naudotojo apibrėžtas",
-    "Open in edit mode" : "Atverti redagavimo veiksenoje",
-    "Open in preview mode" : "Atverti peržiūros veiksenoje",
+    "Rich text" : "Raiškusis tekstas",
+    "Preview" : "Peržiūra",
     "Insert link" : "Įterpti nuorodą",
     "Insert image" : "Įterpti paveikslą",
     "Switch between editor and viewer" : "Perjungti tarp redaktoriaus ir žiūryklės",
-    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
-    "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
-    "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
-    "File extension for new notes" : "Naujų užrašų failo prievardis",
-    "Display mode for notes" : "Užrašų rodinio veiksena",
-    "Action" : "Veiksmas",
     "All notes" : "Visi užrašai",
     "Categories" : "Kategorijos",
     "No notes yet" : "Kol kas užrašų nėra",
     "Select an image" : "Pasirinkite paveikslą",
     "Wrong image" : "Neteisingas paveikslas",
-    "Install the app for your mobile phone in order to access your notes from everywhere." : "Įsidiekite programėlę mobiliajame telefone, kad visur turėtumėte prieigą prie savo užrašų.",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
     "Share" : "Share",
@@ -42,7 +34,6 @@ OC.L10N.register(
     "Empty note" : "Tušti užrašai",
     "Write …" : "Rašykite…",
     "Edit" : "Taisyti",
-    "Preview" : "Peržiūra",
     "Exit full screen" : "Išeiti iš viso ekrano",
     "Full screen" : "Visas ekranas",
     "Note is read-only. You cannot change it." : "Užrašai yra tik skaitymui. Jūs negalite jų keisti.",
@@ -54,7 +45,9 @@ OC.L10N.register(
     "This month" : "Šį mėnesį",
     "Last month" : "Praeitą mėnesį",
     "Loading …" : "Įkeliama…",
+    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
     "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
+    "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Pradėkite rašyti užrašus, spusteldami ant mygtuko „{newnote}“.",
     "Note not found." : "Užrašai nerasti.",
     "Note is locked." : "Užrašai užrakinti.",
