@@ -4,8 +4,8 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Erro",
     "New note" : "Nova nota",
-    "Open in edit mode" : "Abrir no modo de edição",
-    "Open in preview mode" : "Abrir no modo de visualização",
+    "Preview" : "Pré-visualização",
+    "Files" : "Ficheiros",
     "All notes" : "Todas as notas",
     "Categories" : "Categorias",
     "No notes yet" : "Sem notas ainda",
@@ -16,7 +16,6 @@ OC.L10N.register(
     "Delete note" : "Apagar nota",
     "Use current version" : "Usar esta versão",
     "Edit" : "Editar",
-    "Preview" : "Pré-visualização",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "This week" : "Esta semana",
