@@ -4,26 +4,24 @@ OC.L10N.register(
     "Notes" : "Shënime",
     "Error" : "Error",
     "New note" : "Shënim i ri",
-    "Action" : "Veprim",
-    "Open in edit mode" : "Hapur në modalitetin e redaktimit",
-    "Open in preview mode" : "Hape në parapamje",
+    "Preview" : "Parapamje ",
+    "General" : "I përgjithshëm",
+    "Files" : "Skedarët",
     "All notes" : "Të gjitha shënimet",
     "Categories" : "Kategoritë",
     "No notes yet" : "Nuk ka shënime",
-    "Details" : "Detajet",
-    "Delete note" : "Fshije shënimin",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
+    "Share" : "Shpërndaje",
+    "Rename" : "Rename",
+    "Delete note" : "Fshije shënimin",
     "Use current version" : "Përdor versionin aktual",
     "Edit" : "Përpuno",
-    "Preview" : "Parapamje ",
     "Today" : "Sot",
     "Yesterday" : "Dje",
     "This week" : "Këtë javë",
     "This month" : "Këtë muaj",
-    "Category" : "Kategori",
     "Uncategorized" : "Të pakategorizuara",
-    "_%n word_::_%n words_" : ["%n fjalë","%n fjalë"],
     "Tasks" : "Detyra"
 },
 "nplurals=2; plural=(n != 1);");
