@@ -4,9 +4,9 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Error" : "Greška",
     "New note" : "Nova beleška",
-    "Open in edit mode" : "Otvori u režimu uređivanja",
-    "Open in preview mode" : "Otvori u režimu pregleda",
-    "Display mode for notes" : "Režim prikaza beleški",
+    "Preview" : "Pregled",
+    "General" : "Opšte",
+    "Files" : "Фајлови",
     "All notes" : "Sve beleške",
     "No notes yet" : "Još nema beleški",
     "Remove from favorites" : "Remove from favorites",
@@ -14,7 +14,6 @@ OC.L10N.register(
     "Share" : "Podeli",
     "Rename" : "Rename",
     "Edit" : "Uredi",
-    "Preview" : "Pregled",
     "Today" : "Today",
     "Yesterday" : "juče",
     "This week" : "Ove sedmice",
