@@ -4,27 +4,25 @@ OC.L10N.register(
     "Notes" : "Ghi chép",
     "Error" : "Lỗi",
     "New note" : "Ghi chú mới",
-    "Display mode for notes" : "Chế độ hiển thị cho các ghi chú",
-    "Open in edit mode" : "Mở trong chế độ chỉnh sửa",
-    "Open in preview mode" : "Mở trong chế độ xem trước",
+    "Preview" : "Xem trước",
     "Insert image" : "Chèn ảnh",
+    "Files" : "Tệp tin",
     "All notes" : "Tất cả ghi chú",
     "Categories" : "Các hạng mục",
     "No notes yet" : "Chưa có ghi chú",
-    "Share" : "Chia sẻ",
-    "Rename" : "Rename",
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "Add to favorites" : "Thêm vào ưa thích",
+    "Share" : "Chia sẻ",
+    "Rename" : "Rename",
     "Use current version" : "Sử dụng phiên bản hiện tại",
     "Edit" : "Chỉnh sửa",
-    "Preview" : "Xem trước",
-    "Loading …" : "Đang tải...",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
     "This week" : "Tuần này",
     "Last week" : "Tuần trước",
     "This month" : "Tháng này",
     "Last month" : "Tháng trước",
+    "Loading …" : "Đang tải...",
     "Uncategorized" : "Chưa phân loại",
     "Tasks" : "Nhiệm vụ"
 },
