@@ -2,6 +2,12 @@
 
 declare(strict_types=1);
 
+/**
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2013 Bernhard Posselt <nukeawhale@gmail.com>
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 namespace OCA\Notes\Controller;
 
 use OCA\Files\Event\LoadSidebar;
@@ -13,6 +19,9 @@ use OCA\Text\Event\LoadEditor;
 use OCA\Viewer\Event\LoadViewer;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Controller;
+use OCP\AppFramework\Http\Attribute\NoAdminRequired;
+use OCP\AppFramework\Http\Attribute\NoCSRFRequired;
+use OCP\AppFramework\Http\Attribute\UserRateLimit;
 use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\AppFramework\Http\RedirectResponse;
 use OCP\AppFramework\Http\TemplateResponse;
@@ -22,6 +31,7 @@ use OCP\IConfig;
 use OCP\IRequest;
 use OCP\IURLGenerator;
 use OCP\IUserSession;
+use Psr\Log\LoggerInterface;
 
 class PageController extends Controller {
 	private NotesService $notesService;
@@ -30,6 +40,7 @@ class PageController extends Controller {
 	private IURLGenerator $urlGenerator;
 	private IEventDispatcher $eventDispatcher;
 	private IInitialState $initialState;
+	private LoggerInterface $logger;
 
 	public function __construct(
 		string $AppName,
@@ -39,7 +50,8 @@ class PageController extends Controller {
 		IUserSession $userSession,
 		IURLGenerator $urlGenerator,
 		IEventDispatcher $eventDispatcher,
-		IInitialState $initialState
+		IInitialState $initialState,
+		LoggerInterface $logger,
 	) {
 		parent::__construct($AppName, $request);
 		$this->notesService = $notesService;
@@ -48,16 +60,17 @@ class PageController extends Controller {
 		$this->urlGenerator = $urlGenerator;
 		$this->eventDispatcher = $eventDispatcher;
 		$this->initialState = $initialState;
+		$this->logger = $logger;
 	}
 
 
 	/**
-	 * @NoAdminRequired
-	 * @NoCSRFRequired
 	 * @suppress PhanUndeclaredClassReference, PhanTypeMismatchArgument, PhanUndeclaredClassMethod
 	 */
+	#[NoAdminRequired]
+	#[NoCSRFRequired]
 	public function index() : TemplateResponse {
-		$devMode = !is_file(dirname(__FILE__).'/../../js/notes-main.js');
+		$devMode = !is_file(dirname(__FILE__) . '/../../js/notes-main.js');
 		$response = new TemplateResponse(
 			$this->appName,
 			$devMode ? 'dev-mode' : 'main',
@@ -94,11 +107,25 @@ class PageController extends Controller {
 	}
 
 	/**
-	 * @NoAdminRequired
-	 * @NoCSRFRequired
+	 * @deprecated Use createPost() instead. This endpoint will be removed in a future version.
 	 */
-	public function create() : RedirectResponse {
-		$note = $this->notesService->create($this->userSession->getUser()->getUID(), '', '');
+	#[NoAdminRequired]
+	#[NoCSRFRequired]
+	#[UserRateLimit(limit: 20, period: 60)]
+	public function createGet() : RedirectResponse {
+		$this->logger->debug('Deprecated GET /new endpoint used', [
+			'user' => $this->userSession->getUser()?->getUID(),
+			'remote_addr' => $this->request->getRemoteAddress(),
+			'user_agent' => $this->request->getHeader('User-Agent')
+		]);
+		return $this->createPost();
+	}
+
+	#[NoAdminRequired]
+	#[NoCSRFRequired]
+	#[UserRateLimit(limit: 20, period: 60)]
+	public function createPost() : RedirectResponse {
+		$note = $this->notesService->create($this->userSession->getUser()?->getUID() ?? '', '', '');
 		$note->setContent('');
 		$url = $this->urlGenerator->linkToRoute('notes.page.indexnote', [ 'id' => $note->getId() ]);
 		return new RedirectResponse($url . '?new');
